==> scanbot_sdk-1.1.0.tar.gz: android/src/main/kotlin/io/scanbot/sdk/flutter/utils/JsonUtils.java <==
/*
    Scanbot SDK Cordova Plugin

    Copyright (c) 2019 doo GmbH. All rights reserved.
 */
package io.scanbot.sdk.flutter.utils;

import android.graphics.PointF;
import android.graphics.RectF;

import net.doo.snap.lib.detector.DetectionResult;
import net.doo.snap.process.OcrResult;
import net.doo.snap.process.OcrResultBlock;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.scanbot.sdk.persistence.Page;
import io.scanbot.sdk.process.ImageFilterType;

public final class JsonUtils {

    public static JSONObject resultToJson(OcrResult result) throws JSONException {
        JSONObject resultJson = new JSONObject();
        JSONArray pagesJson = new JSONArray();

        for (OcrResult.OCRPage page: result.ocrPages) {
            pagesJson.put(pageToJson(page));
        }

        resultJson.put("pages", pagesJson);
        return resultJson;
    }

    private static JSONObject pageToJson(OcrResult.OCRPage page) throws JSONException {
        JSONObject pageJson = new JSONObject();

        pageJson.put("text", page.text);

        JSONArray wordsJson = new JSONArray();
        for (OcrResultBlock block: page.words) {
            wordsJson.put(blockToJson(block));
        }
        pageJson.put("words", wordsJson);

        JSONArray linesJson = new JSONArray();
        for (OcrResultBlock block: page.lines) {
            linesJson.put(blockToJson(block));
        }
        pageJson.put("lines", linesJson);

        JSONArray paragraphsJson = new JSONArray();
        for (OcrResultBlock block: page.paragraphs) {
            paragraphsJson.put(blockToJson(block));
        }
        pageJson.put("paragraphs", paragraphsJson);

        return  pageJson;
    }

    private static JSONObject blockToJson(OcrResultBlock block) throws JSONException {
        JSONObject blockJson = new JSONObject();

        blockJson.put("boundingBox", boundingBoxToJson(block.boundingBox));
        blockJson.put("text", block.text);
        blockJson.put("confidenceValue", block.confidenceValue);

        return  blockJson;
    }

    private static JSONObject boundingBoxToJson(RectF box) throws JSONException {
        JSONObject boxJson = new JSONObject();

        boxJson.put("x", box.left);
        boxJson.put("y", box.top);
        boxJson.put("width", box.width());
        boxJson.put("height", box.height());

        return  boxJson;
    }

    public static Page.Size sizeFromJson(JSONObject obj) throws JSONException {
        return obj != null ? new Page.Size(obj.getInt("width"), obj.getInt("height")) : new Page.Size();
    }

    public static JSONObject jsonFromSize(Page.Size size) {
        if (size.getWidth() == Integer.MAX_VALUE && size.getHeight() == Integer.MAX_VALUE) {
            return null;
        }
        final Map<String, Object> argsMap = new HashMap<String, Object>();
        argsMap.put("width", size.getWidth());
        argsMap.put("height", size.getHeight());
        return new JSONObject(argsMap);
    }
}

==> scanbot_sdk-2.0.1.tar.gz: android/src/main/kotlin/io/scanbot/sdk/flutter/utils/JsonUtils.java <==
/*
    Scanbot SDK Cordova Plugin

    Copyright (c) 2019 doo GmbH. All rights reserved.
 */
package io.scanbot.sdk.flutter.utils;

import android.graphics.PointF;
import android.graphics.RectF;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import io.scanbot.sdk.ocr.process.OcrResult;
import io.scanbot.sdk.ocr.process.OcrResultBlock;
import io.scanbot.sdk.persistence.Page;
import io.scanbot.sdk.process.ImageFilterType;

public final class JsonUtils {

    public static JSONObject resultToJson(OcrResult result) throws JSONException {
        JSONObject resultJson = new JSONObject();
        JSONArray pagesJson = new JSONArray();

        for (OcrResult.OCRPage page: result.ocrPages) {
            pagesJson.put(pageToJson(page));
        }

        resultJson.put("pages", pagesJson);
        return resultJson;
    }

    private static JSONObject pageToJson(OcrResult.OCRPage page) throws JSONException {
        JSONObject pageJson = new JSONObject();

        pageJson.put("text", page.text);

        JSONArray wordsJson = new JSONArray();
        for (OcrResultBlock block: page.words) {
            wordsJson.put(blockToJson(block));
        }
        pageJson.put("words", wordsJson);

        JSONArray linesJson = new JSONArray();
        for (OcrResultBlock block: page.lines) {
            linesJson.put(blockToJson(block));
        }
        pageJson.put("lines", linesJson);

        JSONArray paragraphsJson = new JSONArray();
        for (OcrResultBlock block: page.paragraphs) {
            paragraphsJson.put(blockToJson(block));
        }
        pageJson.put("paragraphs", paragraphsJson);

        return  pageJson;
    }

    private static JSONObject blockToJson(OcrResultBlock block) throws JSONException {
        JSONObject blockJson = new JSONObject();

        blockJson.put("boundingBox", boundingBoxToJson(block.boundingBox));
        blockJson.put("text", block.text);
        blockJson.put("confidenceValue", block.confidenceValue);

        return  blockJson;
    }

    private static JSONObject boundingBoxToJson(RectF box) throws JSONException {
        JSONObject boxJson = new JSONObject();

        boxJson.put("x", box.left);
        boxJson.put("y", box.top);
        boxJson.put("width", box.width());
        boxJson.put("height", box.height());

        return  boxJson;
    }

    public static Page.Size sizeFromJson(JSONObject obj) throws JSONException {
        return obj != null ? new Page.Size(obj.getInt("width"), obj.getInt("height")) : new Page.Size();
    }

    public static JSONObject jsonFromSize(Page.Size size) {
        if (size.getWidth() == Integer.MAX_VALUE && size.getHeight() == Integer.MAX_VALUE) {
            return null;
        }
        final Map<String, Object> argsMap = new HashMap<String, Object>();
        argsMap.put("width", size.getWidth());
        argsMap.put("height", size.getHeight());
        return new JSONObject(argsMap);
    }
}
